#
# spec file for package ghc-mwc-random
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name mwc-random
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.13.6.0
Release:        lp150.1.8
Summary:        Fast, high quality pseudo random number generation
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-math-functions-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-statistics-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
This package contains code for generating high quality random numbers that
follow either a uniform or normal distribution. The generated numbers are
suitable for use in statistical applications.

The uniform PRNG uses Marsaglia's MWC256 (also known as MWC8222)
multiply-with-carry generator, which has a period of 2^8222 and fares well in
tests of randomness. It is also extremely fast, between 2 and 3 times faster
than the Mersenne Twister.

Compared to the mersenne-random package, this package has a more convenient
API, is faster, and supports more statistical distributions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc README.markdown changelog.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.13.6.0 with cabal2obs.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.13.5.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.13.4.0 revision 0 with cabal2obs.
* Mon Feb 22 2016 mimi.vx@gmail.com
- update to 0.13.4.0
* Mon Sep 14 2015 cfarrell@suse.com
- license update: BSD-2-Clause
  Look at LICENSE file
* Sat Sep 12 2015 mimi.vx@gmail.com
- initial commit
